@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.008-2-g50f29b3
+package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.009-2-g6073d10
 # ABSTRACT: Perform arbitrary commands when Dist::Zilla prompts you
 # KEYWORDS: prompt execute command external
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Moose;
 with 'Dist::Zilla::Role::Plugin';
@@ -52,7 +52,7 @@ around register_component => sub
 __PACKAGE__->meta->make_immutable;
 
 
-package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.008-2-g50f29b3
+package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.009-2-g6073d10
 
 our $VERSION = '0.008';
 
@@ -99,8 +99,7 @@ around [qw(prompt_str prompt_yn)] => sub {
 
     foreach my $warning (<$err>)
     {
-        chomp $warning;
-        warn "[Chrome::ExtraPrompt] $warning\n";
+        warn "[Chrome::ExtraPrompt] $warning";
     }
     my $exit_status = $? >> 8;
     warn "[Chrome::ExtraPrompt] process exited with status $exit_status\n" if $done and $exit_status;
@@ -124,7 +123,7 @@ Dist::Zilla::Plugin::Chrome::ExtraPrompt - Perform arbitrary commands when Dist:
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
